<?php
class MainCest
{
    public function _before(AcceptanceTester $I)
    {
        $I->amOnPage('/?');
    }

    /**
     * Проверка существования списка заданий
     *
     * @param AcceptanceTester $I
     * @return void
     */
    public function tasksListExists(AcceptanceTester $I)
    {
        // Cписок заданий
        $I->waitForElement('#tasks');

        // Строка с колонкой статуса
        $I->waitForElement('//table[@id="tasks"]/tbody/tr/td/i[contains(@class, "task_status")]');

        // Строка с колонкой имени
        $I->waitForElement('//table[@id="tasks"]/tbody/tr/td[@class="task_name"]');

        // Строка с колонкой почты
        $I->waitForElement('//table[@id="tasks"]/tbody/tr/td[@class="task_email"]');

        // Строка с колонкой задания
        $I->waitForElement('//table[@id="tasks"]/tbody/tr/td[@class="task_task"]');

        // Строк три
        // $I->seeNumberOfElements('//table[@id="tasks"]/tbody/tr', 3);
    }

    /**
     * Проверка существования панели создания задания
     *
     * @param AcceptanceTester $I
     * @return void
     */
    public function tasksCreatePanelExists(AcceptanceTester $I)
    {
        // Панель создания заданий
        $I->waitForElement('#tasks_create_panel');
    }

    /**
     * Проверка существования панели авторизации
     *
     * @param AcceptanceTester $I
     * @return void
     */
    public function authPanelExists(AcceptanceTester $I)
    {
        // Панель авторизации
        $I->waitForElement('#sidebar_auth_panel');

        // Первая строка с колонкой задания
        $I->waitForElement('//button[@id="sidebar_auth_button"]');
    }

    /**
     * Проверка вывода ошибки при создании задания без данных
     *
     * @param AcceptanceTester $I
     * @return void
     */
    public function createTaskWithoutData(AcceptanceTester $I)
    {
        // Отправка формы
        $I->click('Добавить');

        // Проверка вывода ошибок
        $I->see('Укажите имя');
        $I->see('Неверный тип почты');
        $I->see('Укажите задание');
    }

    /**
     * Проверка вывода ошибки при введении неверного email
     *
     * @param AcceptanceTester $I
     * @return void
     */
    public function createTaskWithWrongEmail(AcceptanceTester $I)
    {
        // Заполнение полей
        $I->fillField(['name' => 'name'], 'test');
        $I->fillField(['name' => 'email'], 'test');
        $I->fillField(['name' => 'task'], 'test job');

        // Отправка формы
        $I->click('Добавить');

        // Проверка вывода ошибок
        $I->dontSee('Укажите имя');
        $I->see('Неверный тип почты');
        $I->dontSee('Укажите задание');
    }

    /**
     * Проверка вывода ошибки при введении неверного email
     *
     * @param AcceptanceTester $I
     * @return void
     */
    public function createTask(AcceptanceTester $I)
    {
        // Заполнение полей
        $I->fillField(['name' => 'name'], 'test');
        $I->fillField(['name' => 'email'], 'test@test.test');
        $I->fillField(['name' => 'task'], 'test job');

        // Проверка вывода ошибок
        $I->dontSee('Укажите имя');
        $I->dontSee('Неверный тип почты');
        $I->dontSee('Укажите задание');

        // Отправка формы
        $I->click('Добавить');

        $I->waitForText('Задание успешно добавлено!');

        $page = $I->grabTextFrom('//p[@id="pages_сount"]');

        $I->openNewTab($I->executeJS("return location.protocol + '//' + location.host + location.pathname") . '?page=' . $page . '&sort=id');

        $I->waitForElement('//p[@id="page_сurrent"]');
        $current_page = $I->grabTextFrom('//p[@id="page_сurrent"]');

        // Проверка на то, что открыта последняя страница
        if ($page != $current_page) {
            throw new Exception('Не удалось открыть последнюю страницу');
        }

        // Строка с колонкой имени
        echo $name = $I->grabTextFrom('//table[@id="tasks"]/tbody/tr/td[@class="task_name"]');

        // Строка с колонкой почты
        echo $email = $I->grabTextFrom('//table[@id="tasks"]/tbody/tr/td[@class="task_email"]');

        // Строка с колонкой задания
        echo $task = $I->grabTextFrom('//table[@id="tasks"]/tbody/tr/td[@class="task_task"]');
    }
}
